@@ -1,8 +1,10 @@
 import json
 import logging
 from datetime import datetime
+from pathlib import Path
 from pprint import pformat
-from typing import Dict, Optional
+from types import TracebackType
+from typing import Dict, Optional, Any, List, no_type_check, Type
 
 from aiohttp import ClientSession
 from typing_extensions import Self
@@ -35,7 +37,12 @@ class HonAPI:
     async def __aenter__(self) -> Self:
         return await self.create()
 
-    async def __aexit__(self, exc_type, exc_val, exc_tb) -> None:
+    async def __aexit__(
+        self,
+        exc_type: Optional[Type[BaseException]],
+        exc: Optional[BaseException],
+        traceback: Optional[TracebackType],
+    ) -> None:
         await self.close()
 
     @property
@@ -45,13 +52,13 @@ class HonAPI:
         return self._hon.auth
 
     @property
-    def _hon(self):
+    def _hon(self) -> HonConnectionHandler:
         if self._hon_handler is None:
             raise exceptions.NoAuthenticationException
         return self._hon_handler
 
     @property
-    def _hon_anonymous(self):
+    def _hon_anonymous(self) -> HonAnonymousConnectionHandler:
         if self._hon_anonymous_handler is None:
             raise exceptions.NoAuthenticationException
         return self._hon_anonymous_handler
@@ -66,12 +73,18 @@ class HonAPI:
             ).create()
         return self
 
-    async def load_appliances(self) -> Dict:
+    async def load_appliances(self) -> List[Dict[str, Any]]:
         async with self._hon.get(f"{const.API_URL}/commands/v1/appliance") as resp:
-            return await resp.json()
+            result = await resp.json()
+        if result:
+            appliances: List[Dict[str, Any]] = result.get("payload", {}).get(
+                "appliances", {}
+            )
+            return appliances
+        return []
 
-    async def load_commands(self, appliance: HonAppliance) -> Dict:
-        params: Dict = {
+    async def load_commands(self, appliance: HonAppliance) -> Dict[str, Any]:
+        params: Dict[str, str | int] = {
             "applianceType": appliance.appliance_type,
             "applianceModelId": appliance.appliance_model_id,
             "macAddress": appliance.mac_address,
@@ -87,87 +100,99 @@ class HonAPI:
             params["series"] = series
         url: str = f"{const.API_URL}/commands/v1/retrieve"
         async with self._hon.get(url, params=params) as response:
-            result: Dict = (await response.json()).get("payload", {})
+            result: Dict[str, Any] = (await response.json()).get("payload", {})
             if not result or result.pop("resultCode") != "0":
                 _LOGGER.error(await response.json())
                 return {}
             return result
 
-    async def command_history(self, appliance: HonAppliance) -> Dict:
+    async def load_command_history(
+        self, appliance: HonAppliance
+    ) -> List[Dict[str, Any]]:
         url: str = (
             f"{const.API_URL}/commands/v1/appliance/{appliance.mac_address}/history"
         )
         async with self._hon.get(url) as response:
-            result: Dict = await response.json()
-            if not result or not result.get("payload"):
-                return {}
-            return result["payload"]["history"]
+            result: Dict[str, Any] = await response.json()
+        if not result or not result.get("payload"):
+            return []
+        command_history: List[Dict[str, Any]] = result["payload"]["history"]
+        return command_history
 
-    async def command_favourites(self, appliance: HonAppliance) -> Dict:
+    async def load_favourites(self, appliance: HonAppliance) -> List[Dict[str, Any]]:
         url: str = (
             f"{const.API_URL}/commands/v1/appliance/{appliance.mac_address}/favourite"
         )
         async with self._hon.get(url) as response:
-            result: Dict = await response.json()
-            if not result or not result.get("payload"):
-                return {}
-            return result["payload"]["favourites"]
+            result: Dict[str, Any] = await response.json()
+        if not result or not result.get("payload"):
+            return []
+        favourites: List[Dict[str, Any]] = result["payload"]["favourites"]
+        return favourites
 
-    async def last_activity(self, appliance: HonAppliance) -> Dict:
+    async def load_last_activity(self, appliance: HonAppliance) -> Dict[str, Any]:
         url: str = f"{const.API_URL}/commands/v1/retrieve-last-activity"
-        params: Dict = {"macAddress": appliance.mac_address}
+        params: Dict[str, str] = {"macAddress": appliance.mac_address}
         async with self._hon.get(url, params=params) as response:
-            result: Dict = await response.json()
-            if result and (activity := result.get("attributes")):
-                return activity
+            result: Dict[str, Any] = await response.json()
+            if result:
+                activity: Dict[str, Any] = result.get("attributes", "")
+                if activity:
+                    return activity
         return {}
 
-    async def appliance_model(self, appliance: HonAppliance) -> Dict:
+    async def load_appliance_data(self, appliance: HonAppliance) -> Dict[str, Any]:
         url: str = f"{const.API_URL}/commands/v1/appliance-model"
-        params: Dict = {
-            "code": appliance.info["code"],
+        params: Dict[str, str] = {
+            "code": appliance.code,
             "macAddress": appliance.mac_address,
         }
         async with self._hon.get(url, params=params) as response:
-            result: Dict = await response.json()
-            if result and (activity := result.get("attributes")):
-                return activity
+            result: Dict[str, Any] = await response.json()
+            if result:
+                appliance_data: Dict[str, Any] = result.get("payload", {}).get(
+                    "applianceModel", {}
+                )
+                return appliance_data
         return {}
 
-    async def load_attributes(self, appliance: HonAppliance) -> Dict:
-        params: Dict = {
+    async def load_attributes(self, appliance: HonAppliance) -> Dict[str, Any]:
+        params: Dict[str, str] = {
             "macAddress": appliance.mac_address,
             "applianceType": appliance.appliance_type,
             "category": "CYCLE",
         }
         url: str = f"{const.API_URL}/commands/v1/context"
         async with self._hon.get(url, params=params) as response:
-            return (await response.json()).get("payload", {})
+            attributes: Dict[str, Any] = (await response.json()).get("payload", {})
+        return attributes
 
-    async def load_statistics(self, appliance: HonAppliance) -> Dict:
-        params: Dict = {
+    async def load_statistics(self, appliance: HonAppliance) -> Dict[str, Any]:
+        params: Dict[str, str] = {
             "macAddress": appliance.mac_address,
             "applianceType": appliance.appliance_type,
         }
         url: str = f"{const.API_URL}/commands/v1/statistics"
         async with self._hon.get(url, params=params) as response:
-            return (await response.json()).get("payload", {})
+            statistics: Dict[str, Any] = (await response.json()).get("payload", {})
+        return statistics
 
-    async def load_maintenance(self, appliance: HonAppliance):
+    async def load_maintenance(self, appliance: HonAppliance) -> Dict[str, Any]:
         url = f"{const.API_URL}/commands/v1/maintenance-cycle"
         params = {"macAddress": appliance.mac_address}
         async with self._hon.get(url, params=params) as response:
-            return (await response.json()).get("payload", {})
+            maintenance: Dict[str, Any] = (await response.json()).get("payload", {})
+        return maintenance
 
     async def send_command(
         self,
         appliance: HonAppliance,
         command: str,
-        parameters: Dict,
-        ancillary_parameters: Dict,
+        parameters: Dict[str, Any],
+        ancillary_parameters: Dict[str, Any],
     ) -> bool:
         now: str = datetime.utcnow().isoformat()
-        data: Dict = {
+        data: Dict[str, Any] = {
             "macAddress": appliance.mac_address,
             "timestamp": f"{now[:-3]}Z",
             "commandName": command,
@@ -185,24 +210,25 @@ class HonAPI:
         }
         url: str = f"{const.API_URL}/commands/v1/send"
         async with self._hon.post(url, json=data) as response:
-            json_data: Dict = await response.json()
+            json_data: Dict[str, Any] = await response.json()
             if json_data.get("payload", {}).get("resultCode") == "0":
                 return True
             _LOGGER.error(await response.text())
             _LOGGER.error("%s - Payload:\n%s", url, pformat(data))
         return False
 
-    async def appliance_configuration(self) -> Dict:
+    async def appliance_configuration(self) -> Dict[str, Any]:
         url: str = f"{const.API_URL}/config/v1/program-list-rules"
         async with self._hon_anonymous.get(url) as response:
-            result: Dict = await response.json()
-            if result and (data := result.get("payload")):
-                return data
-        return {}
+            result: Dict[str, Any] = await response.json()
+        data: Dict[str, Any] = result.get("payload", {})
+        return data
 
-    async def app_config(self, language: str = "en", beta: bool = True) -> Dict:
+    async def app_config(
+        self, language: str = "en", beta: bool = True
+    ) -> Dict[str, Any]:
         url: str = f"{const.API_URL}/app-config"
-        payload_data: Dict = {
+        payload_data: Dict[str, str | int] = {
             "languageCode": language,
             "beta": beta,
             "appVersion": const.APP_VERSION,
@@ -210,20 +236,89 @@ class HonAPI:
         }
         payload: str = json.dumps(payload_data, separators=(",", ":"))
         async with self._hon_anonymous.post(url, data=payload) as response:
-            if (result := await response.json()) and (data := result.get("payload")):
-                return data
-        return {}
+            result = await response.json()
+        data: Dict[str, Any] = result.get("payload", {})
+        return data
 
-    async def translation_keys(self, language: str = "en") -> Dict:
+    async def translation_keys(self, language: str = "en") -> Dict[str, Any]:
         config = await self.app_config(language=language)
-        if url := config.get("language", {}).get("jsonPath"):
-            async with self._hon_anonymous.get(url) as response:
-                if result := await response.json():
-                    return result
-        return {}
+        if not (url := config.get("language", {}).get("jsonPath")):
+            return {}
+        async with self._hon_anonymous.get(url) as response:
+            result: Dict[str, Any] = await response.json()
+        return result
 
     async def close(self) -> None:
         if self._hon_handler is not None:
             await self._hon_handler.close()
         if self._hon_anonymous_handler is not None:
             await self._hon_anonymous_handler.close()
+
+
+class TestAPI(HonAPI):
+    def __init__(self, path: Path):
+        super().__init__()
+        self._anonymous = True
+        self._path: Path = path
+
+    def _load_json(self, appliance: HonAppliance, file: str) -> Dict[str, Any]:
+        directory = f"{appliance.appliance_type}_{appliance.appliance_model_id}".lower()
+        if not (path := self._path / directory / f"{file}.json").exists():
+            _LOGGER.warning("Can't open %s", str(path))
+            return {}
+        with open(path, "r", encoding="utf-8") as json_file:
+            text = json_file.read()
+        try:
+            data: Dict[str, Any] = json.loads(text)
+            return data
+        except json.decoder.JSONDecodeError as error:
+            _LOGGER.error("%s - %s", str(path), error)
+            return {}
+
+    async def load_appliances(self) -> List[Dict[str, Any]]:
+        result = []
+        for appliance in self._path.glob("*/"):
+            file = appliance / "appliance_data.json"
+            with open(file, "r", encoding="utf-8") as json_file:
+                try:
+                    result.append(json.loads(json_file.read()))
+                except json.decoder.JSONDecodeError as error:
+                    _LOGGER.error("%s - %s", str(file), error)
+        return result
+
+    async def load_commands(self, appliance: HonAppliance) -> Dict[str, Any]:
+        return self._load_json(appliance, "commands")
+
+    @no_type_check
+    async def load_command_history(
+        self, appliance: HonAppliance
+    ) -> List[Dict[str, Any]]:
+        return self._load_json(appliance, "command_history")
+
+    async def load_favourites(self, appliance: HonAppliance) -> List[Dict[str, Any]]:
+        return []
+
+    async def load_last_activity(self, appliance: HonAppliance) -> Dict[str, Any]:
+        return {}
+
+    async def load_appliance_data(self, appliance: HonAppliance) -> Dict[str, Any]:
+        return self._load_json(appliance, "appliance_data")
+
+    async def load_attributes(self, appliance: HonAppliance) -> Dict[str, Any]:
+        return self._load_json(appliance, "attributes")
+
+    async def load_statistics(self, appliance: HonAppliance) -> Dict[str, Any]:
+        return self._load_json(appliance, "statistics")
+
+    async def load_maintenance(self, appliance: HonAppliance) -> Dict[str, Any]:
+        return self._load_json(appliance, "maintenance")
+
+    async def send_command(
+        self,
+        appliance: HonAppliance,
+        command: str,
+        parameters: Dict[str, Any],
+        ancillary_parameters: Dict[str, Any],
+    ) -> bool:
+        _LOGGER.info("%s - %s", str(parameters), str(ancillary_parameters))
+        return True
