@@ -3,19 +3,26 @@ from typing import Dict, Any, List
 from pyhon.parameter.base import HonParameter
 
 
-def clean_value(value):
+def clean_value(value: str | float) -> str:
     return str(value).strip("[]").replace("|", "_").lower()
 
 
 class HonParameterEnum(HonParameter):
     def __init__(self, key: str, attributes: Dict[str, Any], group: str) -> None:
         super().__init__(key, attributes, group)
-        self._default = attributes.get("defaultValue")
-        self._value = self._default or "0"
-        self._values: List[str] = attributes.get("enumValues", [])
+        self._default: str | float = ""
+        self._value: str | float = ""
+        self._values: List[str] = []
+        self._set_attributes()
         if self._default and clean_value(self._default.strip("[]")) not in self.values:
             self._values.append(self._default)
 
+    def _set_attributes(self) -> None:
+        super()._set_attributes()
+        self._default = self._attributes.get("defaultValue", "")
+        self._value = self._default or "0"
+        self._values = self._attributes.get("enumValues", [])
+
     def __repr__(self) -> str:
         return f"{self.__class__} (<{self.key}> {self.values})"
 
@@ -24,7 +31,7 @@ class HonParameterEnum(HonParameter):
         return [clean_value(value) for value in self._values]
 
     @values.setter
-    def values(self, values) -> None:
+    def values(self, values: List[str]) -> None:
         self._values = values
 
     @property
@@ -41,4 +48,4 @@ class HonParameterEnum(HonParameter):
             self._value = value
             self.check_trigger(value)
         else:
-            raise ValueError(f"Allowed values {self._values}")
+            raise ValueError(f"Allowed values: {self._values} But was: {value}")
