@@ -1,25 +1,28 @@
 from typing import Dict, Any, List
 
+from pyhon.helper import str_to_float
 from pyhon.parameter.base import HonParameter
 
 
-def str_to_float(string: str | float) -> float:
-    try:
-        return int(string)
-    except ValueError:
-        return float(str(string).replace(",", "."))
-
-
 class HonParameterRange(HonParameter):
     def __init__(self, key: str, attributes: Dict[str, Any], group: str) -> None:
         super().__init__(key, attributes, group)
-        self._min: float = str_to_float(attributes["minimumValue"])
-        self._max: float = str_to_float(attributes["maximumValue"])
-        self._step: float = str_to_float(attributes["incrementValue"])
-        self._default: float = str_to_float(attributes.get("defaultValue", self.min))
-        self._value: float = self._default
+        self._min: float = 0
+        self._max: float = 0
+        self._step: float = 0
+        self._default: float = 0
+        self._value: float = 0
+        self._set_attributes()
 
-    def __repr__(self):
+    def _set_attributes(self) -> None:
+        super()._set_attributes()
+        self._min = str_to_float(self._attributes.get("minimumValue", 0))
+        self._max = str_to_float(self._attributes.get("maximumValue", 0))
+        self._step = str_to_float(self._attributes.get("incrementValue", 0))
+        self._default = str_to_float(self._attributes.get("defaultValue", self.min))
+        self._value = self._default
+
+    def __repr__(self) -> str:
         return f"{self.__class__} (<{self.key}> [{self.min} - {self.max}])"
 
     @property
@@ -55,11 +58,14 @@ class HonParameterRange(HonParameter):
     @value.setter
     def value(self, value: str | float) -> None:
         value = str_to_float(value)
-        if self.min <= value <= self.max and not (value - self.min) % self.step:
+        if self.min <= value <= self.max and not ((value - self.min) * 100) % (
+            self.step * 100
+        ):
             self._value = value
             self.check_trigger(value)
         else:
-            raise ValueError(f"Allowed: min {self.min} max {self.max} step {self.step}")
+            allowed = f"min {self.min} max {self.max} step {self.step}"
+            raise ValueError(f"Allowed: {allowed} But was: {value}")
 
     @property
     def values(self) -> List[str]:
